package br.com.dclick.model.domain
{
	import br.com.dclick.model.domain.vo.Contact;
	import br.com.dclick.model.domain.vo.Person;
	
	import mx.collections.ArrayCollection;

	/**
	 * 
	 * @author pablo.souza
	 * 
	 * Classe Domain Model da aplicação 
	 * Estrutura dados e define comportamentos
	 * 
	 * Em grandes aplicações, o Domain Model provavelmente seria
	 * dividido em vários, por módulos da aplicação por exemplo.
	 * 
	 */
	
	[Bindable]
	public class AgendaModel
	{
		/* representa Contato selecionado  */
		private var _currentContact:Contact;			
		
		/* representa coleção de Contatos  */
		public var contactsCollection:ArrayCollection;
		
		/* representa coleção de Pessoas  */
		public var personCollection:ArrayCollection;
		
		/* representa Pessoa selecionada  */
		public var currentPerson:Person;
		
		public function set currentContact(pContact:Contact):void
		{
			if(pContact)
			{
				currentPerson = pContact.person;
			} 
			_currentContact = pContact;
		}
		
		/**
		 * 
		 * @return - Retorna o contato selecionado
		 * 
		 */		
		public function get currentContact():Contact
		{
			return _currentContact;
		}
		
		/**
		 * 
		 * @param pId - Id da Pessoa
		 * @return - Retorna a pessoa através do Id
		 * 
		 */		
		public function getPersonById(pId:int):Person
		{
			for (var i:int = 0 ; i < personCollection.length ; i++)
			{
				var person:Person = Person(personCollection.getItemAt(i));
				if(person.idperson == pId)
				{
					return person;
				} 
			}
			
			// caso não tenha sido encontrado nenhuma pessoa com o Id informado
			return null;
		}
		
		/**
		 * 
		 * @param pContact - Contato a ser inserido na coleção
		 * 
		 */		
		public function addContact(pContact:Contact):void
		{
			contactsCollection.addItem(pContact);
		}
		
		/**
		 * 
		 * @param pContact - Contato a ser removido da coleção
		 * 
		 */		
		public function removeContact(pContact:Contact):void
		{
			var i:int = contactsCollection.getItemIndex(pContact);
			contactsCollection.removeItemAt(i);
		}
		
		/**
		 * 
		 * @param pOldContact - Contato que foi modificado
		 * @param pNewContact - Novo contato após modificações
		 * 
		 */		
		public function replaceContacts(pOldContact:Contact, pNewContact:Contact):void
		{
			var i:int = contactsCollection.getItemIndex(pOldContact);
			contactsCollection.setItemAt(pNewContact, i);	
		}
		
		/**
		 * 
		 * @param pNewContact - Novo contato selecionado
		 * 
		 * Substitui csontato pelo novo contato selecionado
		 * 
		 */		
		public function replaceCurrentContact(pNewContact:Contact):void
		{
			replaceContacts(currentContact, pNewContact);
			currentContact = pNewContact;
		}
		
	}
}